@@ -1,27 +1,27 @@
 # ----------------------------------------------------------------------------
-# setup.sh: shell setup for the SpecC system
+# setup.sh: shell setup for the SpecC Reference Compiler
 # ----------------------------------------------------------------------------
 # USAGE: ". $SPECC/bin/setup.sh"
 #
 # author:	Rainer Doemer
-# last update:	April 12, 1999
+# last update:	12/28/01
 
 
 # define the SpecC system home directory
-export SPECC=/home/specc/scrc/public
+export SPECC; SPECC=/home/specc/scrc/public
 
 # extend the search path
-export PATH=$PATH:$SPECC/bin
+export PATH; PATH=$PATH:$SPECC/bin
 
 # extend the manual path
-export MANPATH=$MANPATH:$SPECC/man
+export MANPATH; MANPATH=$MANPATH:$SPECC/man
 
 # extend the search path for dynamically-linked libraries
 # (usually not necessary)
 #if [ -z "$LD_LIBRARY_PATH" ]; then
-#	export LD_LIBRARY_PATH=$SPECC/lib
+#	export LD_LIBRARY_PATH; LD_LIBRARY_PATH=$SPECC/lib;
 #else
-#	export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$SPECC/lib
+#	export LD_LIBRARY_PATH; LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$SPECC/lib;
 #fi
 
 
